@@ -288,7 +288,7 @@ class SingleNetworkApproximator2DSpatialTemporal(Approximator):
 
 
 class FirstOrderInitialCondition:
-    """A first order initial condition. It is used to initialize `temporal.Approximator`s.
+    """A first order initial condition. It is used to initialize ``temporal.Approximator``\s.
 
     :param u0: A function representing the initial condition. If we are solving for
         is :math:`u`, then `u0` is :math:`u\\bigg|_{t=0}`. The input of the function
@@ -304,23 +304,23 @@ class FirstOrderInitialCondition:
 
 
 class SecondOrderInitialCondition:
-    """A second order initial condition. It is used to initialize `temporal.Approximator`s.
+    """A second order initial condition. It is used to initialize ``temporal.Approximator``\s.
 
     :param u0: A function representing the initial condition. If we are solving for
-        is :math:`u`, then `u0` is :math:`u\\bigg|_{t=0}`. The input of the function
+        is :math:`u`, then ``u0`` is :math:`u\\bigg|_{t=0}`. The input of the function
         dependes on where it is used. If it is used as the input for
-        `temporal.SingleNetworkApproximator1DSpatialTemporal`, then `u0` should map
+        ``temporal.SingleNetworkApproximator1DSpatialTemporal``, then ``u0`` should map
         :math:`x` to :math:`u(x, t)\\bigg|_{t = 0}`. If it is used as the input for
-        `temporal.SingleNetworkApproximator2DSpatialTemporal`, then `u0` should map
+        ``temporal.SingleNetworkApproximator2DSpatialTemporal``, then ``u0`` should map
         :math:`(x, y)` to :math:`u(x, y, t)\\bigg|_{t = 0}`.
     :type u0: function
     :param u0dot: A function representing the initial derivative w.r.t. time. If we are solving for
-        is :math:`u`, then `u0dot` is :math:`\\dfrac{\\partial u}{\\partial t}\\bigg|_{t=0}`. 
+        is :math:``u``, then ``u0dot`` is :math:`\\dfrac{\\partial u}{\\partial t}\\bigg|_{t=0}`.
         The input of the function
-        dependes on where it is used. If it is used as the input for
-        `temporal.SingleNetworkApproximator1DSpatialTemporal`, then `u0` should map
+        depends on where it is used. If it is used as the input for
+        ``temporal.SingleNetworkApproximator1DSpatialTemporal``, then ``u0`` should map
         :math:`x` to :math:`\\dfrac{\\partial u}{\\partial t}\\bigg|_{t = 0}`. If it is used as the input for
-        `temporal.SingleNetworkApproximator2DSpatialTemporal`, then `u0` should map
+        `temporal.SingleNetworkApproximator2DSpatialTemporal`, then ``u0`` should map
         :math:`(x, y)` to :math:`\\dfrac{\\partial u}{\\partial t}\\bigg|_{t = 0}`.
     :type u0dot: function
     """
@@ -330,14 +330,14 @@ class SecondOrderInitialCondition:
 
 
 class BoundaryCondition:
-    """A boundary condition. It is used to initialize `temporal.Approximator`s.
+    """A boundary condition. It is used to initialize ``temporal.Approximator``\s.
 
-    :param form: The form of the boundary condition. For a 1D time-dependent problem, if the boundary condition demands that :math:`B(u, x) = 0`, then `form` should be a function that map :math:`u, x, t` to :math:`B(u, x)`. For a 2D steady-state problem, if the boundary condition demands that :math:`B(u, x, y) = 0`, then `form` should be a function that map :math:`u, x, y` to :math:`B(u, x, y)`. For a 2D steady-state system, if the boundary condition demands that :math:`B(u_i, x, y) = 0`, then `form` should be a function that map :math:`u_1, u_2, ..., u_n, x, y` to `B(u_i, x, y)`. For 2D time-dependent problem, if the boundary condition demands that :math:`B(u, x, y) = 0`, then `form` should be a function that map :math:`u, x, y, t` to `B(u_i, x, y)`. Basically the function signature of `form` should be the same as the `pde` function of the given `temporal.Approximator`.
-    :type form: funcion
-    :param points_generator: A generator that generate points on the boundary.
+    :param form: The form of the boundary condition. For a 1D time-dependent problem, if the boundary condition demands that :math:`B(u, x) = 0`, then ``form`` should be a function that maps :math:`u, x, t` to :math:`B(u, x)`. For a 2D steady-state problem, if the boundary condition demands that :math:`B(u, x, y) = 0`, then ``form`` should be a function that maps :math:`u, x, y` to :math:`B(u, x, y)`. For a 2D steady-state system, if the boundary condition demands that :math:`B(u_i, x, y) = 0`, then `form` should be a function that maps :math:`u_1, u_2, ..., u_n, x, y` to `B(u_i, x, y)`. For 2D time-dependent problem, if the boundary condition demands that :math:`B(u, x, y) = 0`, then `form` should be a function that maps :math:`u, x, y, t` to `B(u_i, x, y)`. Basically the function signature of ``form`` should be the same as the ``pde`` function of the given ``temporal.Approximator``.
+    :type form: callable
+    :param points_generator: A generator that generates points on the boundary.
         It can be a `temporal.generator_1dspatial`, `temporal.generator_2dspatial_segment`,
         or a generator written by user.
-    :type points_generator: generator
+    :type points_genrator: generator
     """
     def __init__(self, form, points_generator):
         self.form = form
@@ -455,7 +455,7 @@ class MonitorMinimal:
     """A monitor that shows the loss function and custom metrics.
     """
     def __init__(self, check_every):
-        self.using_non_gui_backend = matplotlib.get_backend() is 'agg'
+        self.using_non_gui_backend = matplotlib.get_backend() == 'agg'
         self.check_every = check_every
 
         self.fig = plt.figure(figsize=(20, 8))
@@ -495,7 +495,7 @@ class Monitor1DSpatialTemporal:
     """A monitor for 1D time-dependent problems.
     """
     def __init__(self, check_on_x, check_on_t, check_every):
-        self.using_non_gui_backend = matplotlib.get_backend() is 'agg'
+        self.using_non_gui_backend = matplotlib.get_backend() == 'agg'
 
         self.xx_tensor, self.tt_tensor = _cartesian_prod_dims(check_on_x, check_on_t)
         self.x_array = check_on_x.clone().detach().cpu().numpy()
@@ -553,7 +553,7 @@ class Monitor2DSpatialTemporal:
     """A monitor for 2D time-dependent problems.
     """
     def __init__(self, check_on_x, check_on_y, check_on_t, check_every):
-        self.using_non_gui_backend = matplotlib.get_backend() is 'agg'
+        self.using_non_gui_backend = matplotlib.get_backend() == 'agg'
 
         xy_tensor = torch.cartesian_prod(check_on_x, check_on_y)
         self.xx_tensor = torch.squeeze(xy_tensor[:, 0])
@@ -634,7 +634,7 @@ class Monitor2DSpatial:
     """A Monitor for 2D steady-state problems
     """
     def __init__(self, check_on_x, check_on_y, check_every):
-        self.using_non_gui_backend = matplotlib.get_backend() is 'agg'
+        self.using_non_gui_backend = matplotlib.get_backend() == 'agg'
 
         xy_tensor = torch.cartesian_prod(check_on_x, check_on_y)
         self.xx_tensor = torch.squeeze(xy_tensor[:, 0])
