@@ -3,12 +3,12 @@ from numpy import isclose
 import matplotlib
 matplotlib.use('Agg') # use a non-GUI backend, so plots are not shown during testing
 
-from neurodiffeq import diff
+from neurodiffeq.neurodiffeq import safe_diff as diff
 from neurodiffeq.networks import FCNN
-from neurodiffeq.pde import DirichletBVP2D, IBVP1D, Condition,_network_output_2input
+from neurodiffeq.pde import DirichletBVP2D, IBVP1D
 from neurodiffeq.pde import DirichletControlPoint, NeumannControlPoint, Point, CustomBoundaryCondition
-from neurodiffeq.generator import PredefinedGenerator, Generator2D
-from neurodiffeq.pde import solve2D, solve2D_system, Monitor2D, make_animation, set_default_dtype
+from neurodiffeq.generators import PredefinedGenerator, Generator2D
+from neurodiffeq.pde import solve2D, solve2D_system, Monitor2D, make_animation
 
 from pytest import raises
 
@@ -29,7 +29,7 @@ def test_monitor():
         y_max=1, y_max_val=lambda x: 0
     )
 
-    net = FCNN(n_input_units=2, n_hidden_units=32, n_hidden_layers=1)
+    net = FCNN(n_input_units=2, hidden_units=(32, 32))
     solution_neural_net_laplace, _ = solve2D(
         pde=laplace, condition=bc, xy_min=(0, 0), xy_max=(1, 1),
         net=net, max_epochs=3,
@@ -49,7 +49,7 @@ def test_train_generator():
         y_max=1, y_max_val=lambda x: 0
     )
 
-    net = FCNN(n_input_units=2, n_hidden_units=32, n_hidden_layers=1)
+    net = FCNN(n_input_units=2, hidden_units=(32, 32))
     solution_neural_net_laplace, _ = solve2D(
         pde=laplace, condition=bc, xy_min=(0, 0), xy_max=(1, 1),
         net=net, max_epochs=3,
@@ -87,22 +87,6 @@ def test_train_generator():
         )
 
 
-def test_ibvp():
-    with raises(NotImplementedError):
-        IBVP1D(
-            t_min=0, t_min_val=lambda x: 0,
-            x_min=0, x_min_val=lambda t: None, x_min_prime=lambda t: None,
-            x_max=1, x_max_val=lambda t: None, x_max_prime=lambda t: None,
-        )
-    with raises(NotImplementedError):
-        IBVP1D(
-            t_min=0, t_min_val=lambda x: 0,
-            x_min=0, x_min_val=lambda t: 0, x_min_prime=lambda t: 0,
-            x_max=1, x_max_val=lambda t: None, x_max_prime=lambda t: None,
-        )
-    print('IBVP test passed.')
-
-
 def test_laplace():
 
     laplace = lambda u, x, y: diff(u, x, order=2) + diff(u, y, order=2)
@@ -113,7 +97,7 @@ def test_laplace():
         y_max=1, y_max_val=lambda x: 0
     )
 
-    net = FCNN(n_input_units=2, n_hidden_units=32, n_hidden_layers=1)
+    net = FCNN(n_input_units=2, hidden_units=(32, 32))
     solution_neural_net_laplace, _ = solve2D(
         pde=laplace, condition=bc, xy_min=(0, 0), xy_max=(1, 1),
         net=net, max_epochs=300,
@@ -140,7 +124,7 @@ def test_heat():
         x_max=L, x_max_val=lambda t: 0,
         t_min=0, t_min_val=lambda x: torch.sin(np.pi * x / L)
     )
-    net = FCNN(n_input_units=2, n_hidden_units=32, n_hidden_layers=1)
+    net = FCNN(n_input_units=2, hidden_units=(32,32))
 
     def mse(u, x, y):
         true_u = torch.sin(np.pi * y) * torch.sinh(np.pi * (1 - x)) / np.sinh(np.pi)
@@ -177,7 +161,7 @@ def test_neumann_boundaries_1():
         t_min=0, t_min_val=lambda x: torch.sin(np.pi * x / L)
     )
 
-    net = FCNN(n_input_units=2, n_hidden_units=32, n_hidden_layers=1)
+    net = FCNN(n_input_units=2, hidden_units=(32, 32))
 
     solution_neural_net_heat, _ = solve2D(
         pde=heat, condition=ibvp, xy_min=(0, 0), xy_max=(L, T),
@@ -208,7 +192,7 @@ def test_neumann_boundaries_2():
         t_min=0, t_min_val=lambda x: torch.sin(np.pi * x / L)
     )
 
-    net = FCNN(n_input_units=2, n_hidden_units=32, n_hidden_layers=1)
+    net = FCNN(n_input_units=2, hidden_units=(32, 32))
 
     solution_neural_net_heat, _ = solve2D(
         pde=heat, condition=ibvp, xy_min=(0, 0), xy_max=(L, T),
@@ -238,7 +222,7 @@ def test_neumann_boundaries_3():
         t_min=0, t_min_val=lambda x: torch.sin(np.pi * x / L)
     )
 
-    net = FCNN(n_input_units=2, n_hidden_units=32, n_hidden_layers=1)
+    net = FCNN(n_input_units=2, hidden_units=(32, 32))
 
     solution_neural_net_heat, _ = solve2D(
         pde=heat, condition=ibvp, xy_min=(0, 0), xy_max=(L, T),
@@ -345,7 +329,7 @@ def test_neumann_boundaries_3():
 #     conditions = [bc_on_u, bc_on_v, bc_on_p]
 #
 #     nets = [
-#         FCNN(n_input_units=2, n_hidden_units=32, n_hidden_layers=1, actv=nn.Softplus)
+#         FCNN(n_input_units=2, hidden_units=(32, 32), actv=nn.Softplus)
 #         for _ in range(3)
 #     ]
 #
@@ -541,7 +525,7 @@ def test_arbitrary_boundary():
                     1.0 + x ** 2 + y ** 2) ** 2
 
     # fully connected network with one hidden layer (100 hidden units with ELU activation)
-    net = FCNN(n_input_units=2, n_hidden_units=100, n_hidden_layers=1, actv=nn.ELU)
+    net = FCNN(n_input_units=2, hidden_units=(100, 100), actv=nn.ELU)
     adam = optim.Adam(params=net.parameters(), lr=0.001)
 
     # train on 28 X 28 grid
